@@ -457,13 +457,13 @@ class FeaturesAssembler(AbstractAssembler):
         print('Min price date '+str(min(df_ret.index)))
 
 
-        print('Actual min shortcut feature date '+str(min(shortcut_features_df.index)))
-        print('Actual max shortcut feature date '+str(max(shortcut_features_df.index)))
+        print('Actual min shortcut feature date '+str(min(shortcut_features_df['Date'])))
+        print('Actual max shortcut feature date '+str(max(shortcut_features_df['Date'])))
 
-        shortcut_features_df = shortcut_features_df[shortcut_features_df.index >= self.starting_date]
-        shortcut_features_df = shortcut_features_df[shortcut_features_df.index <= self.ending_date]
-        print('Max shortcut date '+str(max(shortcut_features_df.index)))
-        print('Min shortcut date '+str(min(shortcut_features_df.index)))
+        shortcut_features_df = shortcut_features_df[shortcut_features_df['Date'] >= self.starting_date]
+        shortcut_features_df = shortcut_features_df[shortcut_features_df['Date'] <= self.ending_date]
+        print('Max shortcut date '+str(max(shortcut_features_df['Date'])))
+        print('Min shortcut date '+str(min(shortcut_features_df['Date'])))
 
 
         # quotes_df=quotes_df.sort_values(by='date', ascending=True)
