@@ -104,7 +104,7 @@ class NaPoleonDropboxConnector(object):
         results = np.load(local_supervision_npy_path)
         return results
 
-    def local_features_npy_save_and_upload(self, starting_date = None, ending_date = None, features=None, features_names=None, feature_type=None, n_past_features = None, local_root_directory='', user='', features_saving_suffix='', features_names_saving_suffix=''):
+    def local_features_npy_save_and_upload(self, starting_date = None, ending_date = None, shortcut_features=None, features=None, features_names=None, feature_type=None, n_past_features = None, local_root_directory='', user='', shortcut_features_saving_suffix='',features_saving_suffix='', features_names_saving_suffix=''):
         features_file_name = starting_date.strftime('%d_%b_%Y')+'_'+ending_date.strftime('%d_%b_%Y')+'_'+user +'_' + feature_type.name + '_' + str(n_past_features) + features_saving_suffix
         local_root_directory = Path(local_root_directory)
         features_full_path = local_root_directory/features_file_name
@@ -118,6 +118,14 @@ class NaPoleonDropboxConnector(object):
         if self.dropbox_backup:
             self.upload(fullname=features_names_full_path, folder='', subfolder='', name = features_names_file_names, overwrite=self.overwrite)
 
+        shortcut_features_file_name = starting_date.strftime('%d_%b_%Y')+'_'+ending_date.strftime('%d_%b_%Y')+'_'+user +'_'+ shortcut_features_saving_suffix
+        local_root_directory = Path(local_root_directory)
+        shortcut_features_full_path = local_root_directory/shortcut_features_file_name
+        print('saving local file '+str(shortcut_features_full_path))
+        np.save(shortcut_features_full_path, shortcut_features)
+        if self.dropbox_backup:
+            self.upload(fullname=shortcut_features_full_path, folder='', subfolder='', name = shortcut_features_file_name, overwrite=self.overwrite)
+
     def local_supervision_npy_save_and_upload(self, starting_date = None, ending_date = None, data=None, rebal = None, lower_bound=0.02, upper_bound=0.4, local_root_directory='', user='', supervision_npy_file_suffix=''):
         supervision_file_name = starting_date.strftime('%d_%b_%Y') + '_' +ending_date.strftime('%d_%b_%Y') + '_'+ user + '_' + str(rebal) + '_' + str(lower_bound)+ '_' + str(upper_bound) + supervision_npy_file_suffix
         local_root_directory = Path(local_root_directory)
